NapaAnimatedContainer class
Wrapper class for AnimatedContainer. https://api.flutter.dev/flutter/widgets/AnimatedContainer-class.html
- Inheritance
-
- Object
- NapaWidget
- NapaStatelessWidget
- NapaAnimatedContainer
Constructors
- NapaAnimatedContainer({AlignmentGeometry? alignment, EdgeInsetsGeometry? padding, Color? color, double? width, double? height, BoxConstraints? constraints, EdgeInsetsGeometry? margin, NapaMatrix4Compose? transform, AlignmentGeometry? transformAlignment, Clip clipBehavior = Clip.none, required Duration duration, Curve curve = Curves.linear, NapaWidget? child})
Properties
- alignment ↔ AlignmentGeometry?
-
getter/setter pair
- child ↔ NapaWidget?
-
getter/setter pair
- childMode → NapaChildMode
-
finalinherited
- clipBehavior ↔ Clip
-
getter/setter pair
- color ↔ Color?
-
getter/setter pair
- constraints ↔ BoxConstraints?
-
getter/setter pair
- curve ↔ Curve
-
getter/setter pair
- duration ↔ Duration
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ double?
-
getter/setter pair
- margin ↔ EdgeInsetsGeometry?
-
getter/setter pair
- padding ↔ EdgeInsetsGeometry?
-
getter/setter pair
-
properties
↔ List<
InspectableProperty> -
The list of inspectable property descriptors for this object.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transform ↔ NapaMatrix4Compose?
-
getter/setter pair
- transformAlignment ↔ AlignmentGeometry?
-
getter/setter pair
- widgetName → String
-
no setteroverride
- width ↔ double?
-
getter/setter pair
Methods
-
getProperty(
String name) → InspectableProperty? -
Returns the first property whose
InspectableProperty.namematchesname, ornullif no such property exists.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeProperty(
String name) → void -
Removes the property with the given
namefromproperties.inherited -
toJson(
) → dynamic -
toJson returns a json compatible object.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
toWidget(
) → Widget -
Get a Flutter widget equivalent object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
dynamic data) → NapaAnimatedContainer? -
Deserialize a json compatible object into a NapaWidget or null.
override