NapaAnimatedSwitcher class
Wrapper class for AnimatedSwitcher. https://api.flutter.dev/flutter/widgets/AnimatedSwitcher-class.html
- Inheritance
-
- Object
- NapaWidget
- NapaStatelessWidget
- NapaAnimatedSwitcher
Constructors
- NapaAnimatedSwitcher({required Duration duration, Duration? reverseDuration, Curve switchInCurve = Curves.linear, Curve switchOutCurve = Curves.linear, NapaWidget? child})
Properties
- child ↔ NapaWidget?
-
getter/setter pair
- childMode → NapaChildMode
-
finalinherited
- duration ↔ Duration
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
properties
↔ List<
InspectableProperty> -
The list of inspectable property descriptors for this object.
getter/setter pairinherited
- reverseDuration ↔ Duration?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- switchInCurve ↔ Curve
-
getter/setter pair
- switchOutCurve ↔ Curve
-
getter/setter pair
- widgetName → String
-
no setteroverride
Methods
-
getProperty(
String name) → InspectableProperty? -
Returns the first property whose
InspectableProperty.namematchesname, ornullif no such property exists.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeProperty(
String name) → void -
Removes the property with the given
namefromproperties.inherited -
toJson(
) → dynamic -
toJson returns a json compatible object.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
toWidget(
) → Widget -
Get a Flutter widget equivalent object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
dynamic data) → NapaAnimatedSwitcher? -
Deserialize a json compatible object into a NapaWidget or null.
override