NapaCustomPaint class

Inheritance

Constructors

NapaCustomPaint({NapaCustomPainter? painter, NapaCustomPainter? foregroundPainter, Size size = Size.zero, bool isComplex = false, bool willChange = false, NapaWidget? child})

Properties

child NapaWidget?
getter/setter pairinherited
childMode NapaChildMode
finalinherited
foregroundPainter NapaCustomPainter?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isComplex bool
getter/setter pair
painter NapaCustomPainter?
getter/setter pair
properties List<InspectableProperty>
The list of inspectable property descriptors for this object.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size
getter/setter pair
widgetName String
no setteroverride
willChange bool
getter/setter pair

Methods

getProperty(String name) → InspectableProperty?
Returns the first property whose InspectableProperty.name matches name, or null if no such property exists.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeProperty(String name) → void
Removes the property with the given name from properties.
inherited
toJson() → dynamic
toJson returns a json compatible object.
override
toString() String
A string representation of this object.
inherited
toWidget() Widget
Get a Flutter widget equivalent object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(dynamic data) NapaCustomPaint?
Deserialize a json compatible object into a NapaWidget or null.
override