NapaGridView class

Inheritance

Constructors

NapaGridView({Axis scrollDirection = Axis.vertical, bool reverse = false, bool? primary, ScrollPhysics? physics, bool shrinkWrap = false, EdgeInsetsGeometry? padding, int crossAxisCount = 2, double mainAxisSpacing = 0.0, double crossAxisSpacing = 0.0, double childAspectRatio = 1.0, bool addAutomaticKeepAlives = true, bool addRepaintBoundaries = true, bool addSemanticIndexes = true, double? cacheExtent, List<NapaWidget>? children, int? semanticChildCount, DragStartBehavior dragStartBehavior = .start, ScrollViewKeyboardDismissBehavior? keyboardDismissBehavior, Clip clipBehavior = .hardEdge, HitTestBehavior hitTestBehavior = .opaque})

Properties

addAutomaticKeepAlives bool
getter/setter pair
addRepaintBoundaries bool
getter/setter pair
addSemanticIndexes bool
getter/setter pair
anchor double
getter/setter pairinherited
cacheExtent double?
getter/setter pairinherited
childAspectRatio double
getter/setter pair
childMode NapaChildMode
finalinherited
children List<NapaWidget>
getter/setter pair
clipBehavior Clip
getter/setter pairinherited
crossAxisCount int
getter/setter pair
crossAxisSpacing double
getter/setter pair
dragStartBehavior DragStartBehavior
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
hitTestBehavior HitTestBehavior
getter/setter pairinherited
keyboardDismissBehavior ScrollViewKeyboardDismissBehavior?
getter/setter pairinherited
mainAxisSpacing double
getter/setter pair
padding EdgeInsetsGeometry?
getter/setter pairinherited
paintOrder SliverPaintOrder
getter/setter pairinherited
physics ScrollPhysics?
getter/setter pairinherited
primary bool?
getter/setter pairinherited
properties List<InspectableProperty>
The list of inspectable property descriptors for this object.
getter/setter pairinherited
reverse bool
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollBehavior ScrollBehavior?
getter/setter pairinherited
scrollDirection Axis
getter/setter pairinherited
semanticChildCount int?
getter/setter pairinherited
shrinkWrap bool
getter/setter pairinherited
widgetName String
no setteroverride

Methods

getProperty(String name) → InspectableProperty?
Returns the first property whose InspectableProperty.name matches name, or null if no such property exists.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeProperty(String name) → void
Removes the property with the given name from properties.
inherited
toJson() → dynamic
toJson returns a json compatible object.
override
toString() String
A string representation of this object.
inherited
toWidget() Widget
Get a Flutter widget equivalent object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(dynamic data) NapaGridView?
Deserialize a json compatible object into a NapaWidget or null.
override