NapaOverflowBox class
Wrapper class for OverflowBox. https://api.flutter.dev/flutter/widgets/OverflowBox-class.html
- Inheritance
-
- Object
- NapaWidget
- NapaRenderObjectWidget
- NapaSingleChildRenderObjectWidget
- NapaOverflowBox
Constructors
- NapaOverflowBox({AlignmentGeometry alignment = Alignment.center, double? minWidth, double? maxWidth, double? minHeight, double? maxHeight, NapaWidget? child})
Properties
- alignment ↔ AlignmentGeometry
-
getter/setter pair
- child ↔ NapaWidget?
-
getter/setter pairinherited
- childMode → NapaChildMode
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxHeight ↔ double?
-
getter/setter pair
- maxWidth ↔ double?
-
getter/setter pair
- minHeight ↔ double?
-
getter/setter pair
- minWidth ↔ double?
-
getter/setter pair
-
properties
↔ List<
InspectableProperty> -
The list of inspectable property descriptors for this object.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widgetName → String
-
no setteroverride
Methods
-
getProperty(
String name) → InspectableProperty? -
Returns the first property whose
InspectableProperty.namematchesname, ornullif no such property exists.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeProperty(
String name) → void -
Removes the property with the given
namefromproperties.inherited -
toJson(
) → dynamic -
toJson returns a json compatible object.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
toWidget(
) → Widget -
Get a Flutter widget equivalent object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
dynamic data) → NapaOverflowBox? -
Deserialize a json compatible object into a NapaWidget or null.
override