NapaPageView class

Inheritance

Constructors

NapaPageView({Axis scrollDirection = Axis.horizontal, bool reverse = false, bool pageSnapping = true, bool allowImplicitScrolling = false, Clip clipBehavior = Clip.hardEdge, bool padEnds = true, DragStartBehavior dragStartBehavior = DragStartBehavior.start, List<NapaWidget>? children})

Properties

allowImplicitScrolling bool
getter/setter pair
childMode NapaChildMode
finalinherited
children List<NapaWidget>
getter/setter pair
clipBehavior Clip
getter/setter pair
dragStartBehavior DragStartBehavior
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
padEnds bool
getter/setter pair
pageSnapping bool
getter/setter pair
properties List<InspectableProperty>
The list of inspectable property descriptors for this object.
getter/setter pairinherited
reverse bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollDirection Axis
getter/setter pair
widgetName String
no setteroverride

Methods

getProperty(String name) → InspectableProperty?
Returns the first property whose InspectableProperty.name matches name, or null if no such property exists.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeProperty(String name) → void
Removes the property with the given name from properties.
inherited
toJson() → dynamic
toJson returns a json compatible object.
override
toString() String
A string representation of this object.
inherited
toWidget() Widget
Get a Flutter widget equivalent object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(dynamic data) NapaPageView?
Deserialize a json compatible object into a NapaWidget or null.
override