NapaProxyWidget class abstract

Inheritance
Implementers

Constructors

NapaProxyWidget({required NapaWidget child})

Properties

child NapaWidget
getter/setter pair
childMode NapaChildMode
finalinherited
hashCode int
The hash code for this object.
no setterinherited
properties List<InspectableProperty>
The list of inspectable property descriptors for this object.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widgetName String
no setteroverride

Methods

getProperty(String name) → InspectableProperty?
Returns the first property whose InspectableProperty.name matches name, or null if no such property exists.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeProperty(String name) → void
Removes the property with the given name from properties.
inherited
toJson() → dynamic
toJson returns a json compatible object.
override
toString() String
A string representation of this object.
inherited
toWidget() Widget
Get a Flutter widget equivalent object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited