NapaSafeArea class

Inheritance

Constructors

NapaSafeArea({bool left = true, bool top = true, bool right = true, bool bottom = true, EdgeInsets minimum = EdgeInsets.zero, bool maintainBottomViewPadding = false, NapaWidget? child})

Properties

bottom bool
getter/setter pair
child NapaWidget?
getter/setter pair
childMode NapaChildMode
finalinherited
hashCode int
The hash code for this object.
no setterinherited
left bool
getter/setter pair
maintainBottomViewPadding bool
getter/setter pair
minimum EdgeInsets
getter/setter pair
properties List<InspectableProperty>
The list of inspectable property descriptors for this object.
getter/setter pairinherited
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top bool
getter/setter pair
widgetName String
no setteroverride

Methods

getProperty(String name) → InspectableProperty?
Returns the first property whose InspectableProperty.name matches name, or null if no such property exists.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeProperty(String name) → void
Removes the property with the given name from properties.
inherited
toJson() → dynamic
toJson returns a json compatible object.
override
toString() String
A string representation of this object.
inherited
toWidget() Widget
Get a Flutter widget equivalent object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(dynamic data) NapaSafeArea?
Deserialize a json compatible object into a NapaWidget or null.
override