toJson method
toJson returns a json compatible object.
Descendants must override this method to expose custom properties.
Implementation
@override
toJson() {
return super.toJson()..addAll({'transform': transform.toJson()});
}
toJson returns a json compatible object.
Descendants must override this method to expose custom properties.
@override
toJson() {
return super.toJson()..addAll({'transform': transform.toJson()});
}