NapaWrap class

Inheritance

Constructors

NapaWrap({WrapAlignment alignment = .start, Clip clipBehavior = .none, WrapCrossAlignment crossAxisAlignment = .start, Axis direction = .horizontal, WrapAlignment runAlignment = .start, double runSpacing = 0.0, double spacing = 0.0, TextDirection? textDirection, VerticalDirection verticalDirection = .down, List<NapaWidget>? children})

Properties

alignment WrapAlignment
getter/setter pair
childMode NapaChildMode
finalinherited
children List<NapaWidget>
getter/setter pairinherited
clipBehavior Clip
getter/setter pair
crossAxisAlignment WrapCrossAlignment
getter/setter pair
direction Axis
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
properties List<InspectableProperty>
The list of inspectable property descriptors for this object.
getter/setter pairinherited
runAlignment WrapAlignment
getter/setter pair
runSpacing double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double
getter/setter pair
textDirection TextDirection?
getter/setter pair
verticalDirection VerticalDirection
getter/setter pair
widgetName String
no setteroverride

Methods

getProperty(String name) → InspectableProperty?
Returns the first property whose InspectableProperty.name matches name, or null if no such property exists.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeProperty(String name) → void
Removes the property with the given name from properties.
inherited
toJson() → dynamic
toJson returns a json compatible object.
override
toString() String
A string representation of this object.
inherited
toWidget() Widget
Get a Flutter widget equivalent object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(dynamic data) NapaWrap?
Deserialize a json compatible object into a NapaWidget or null.
override