NapaTextSpan class
Serializable wrapper for TextSpan.
Constructors
-
NapaTextSpan({String? text, NapaTextStyle? style, String? semanticsLabel, List<
NapaTextSpan> ? children})
Properties
-
children
↔ List<
NapaTextSpan> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticsLabel ↔ String?
-
getter/setter pair
- style ↔ NapaTextStyle?
-
getter/setter pair
- text ↔ String?
-
getter/setter pair
- textSpan → TextSpan
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → dynamic -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
dynamic data) → NapaTextSpan?