NapaIcon class
Wrapper class for Icon. https://api.flutter.dev/flutter/widgets/Icon-class.html
- Inheritance
-
- Object
- NapaWidget
- NapaStatelessWidget
- NapaIcon
Constructors
Properties
- applyTextScaling ↔ bool?
-
getter/setter pair
- blendMode ↔ BlendMode?
-
getter/setter pair
- childMode → NapaChildMode
-
finalinherited
- color ↔ Color?
-
getter/setter pair
- fill ↔ double?
-
getter/setter pair
- fontWeight ↔ FontWeight?
-
getter/setter pair
- grade ↔ double?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon ↔ IconData?
-
getter/setter pair
- opticalSize ↔ double?
-
getter/setter pair
-
properties
↔ List<
InspectableProperty> -
The list of inspectable property descriptors for this object.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel ↔ String?
-
getter/setter pair
-
shadows
↔ List<
Shadow> ? -
getter/setter pair
- size ↔ double?
-
getter/setter pair
- textDirection ↔ TextDirection?
-
getter/setter pair
- weight ↔ double?
-
getter/setter pair
- widgetName → String
-
no setteroverride
Methods
-
getProperty(
String name) → InspectableProperty? -
Returns the first property whose
InspectableProperty.namematchesname, ornullif no such property exists.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeProperty(
String name) → void -
Removes the property with the given
namefromproperties.inherited -
toJson(
) → dynamic -
toJson returns a json compatible object.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
toWidget(
) → Widget -
Get a Flutter widget equivalent object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited