NapaSemantics class
Wrapper class for Semantics. https://api.flutter.dev/flutter/widgets/Semantics-class.html
- Inheritance
-
- Object
- NapaWidget
- NapaStatelessWidget
- NapaSemantics
Constructors
- NapaSemantics({bool container = false, bool explicitChildNodes = false, bool excludeSemantics = false, bool? enabled, bool? checked, bool? selected, bool? button, bool? link, bool? header, bool? textField, bool? readOnly, bool? focusable, bool? focused, bool? image, bool? liveRegion, bool? obscured, bool? multiline, bool? scopesRoute, bool? namesRoute, String? label, String? value, String? hint, NapaWidget? child})
Properties
-
getter/setter pair
- checked ↔ bool?
-
getter/setter pair
- child ↔ NapaWidget?
-
getter/setter pair
- childMode → NapaChildMode
-
finalinherited
- container ↔ bool
-
getter/setter pair
- enabled ↔ bool?
-
getter/setter pair
- excludeSemantics ↔ bool
-
getter/setter pair
- explicitChildNodes ↔ bool
-
getter/setter pair
- focusable ↔ bool?
-
getter/setter pair
- focused ↔ bool?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- header ↔ bool?
-
getter/setter pair
-
getter/setter pair
- hint ↔ String?
-
getter/setter pair
- image ↔ bool?
-
getter/setter pair
- label ↔ String?
-
getter/setter pair
- link ↔ bool?
-
getter/setter pair
- liveRegion ↔ bool?
-
getter/setter pair
- multiline ↔ bool?
-
getter/setter pair
- namesRoute ↔ bool?
-
getter/setter pair
- obscured ↔ bool?
-
getter/setter pair
-
properties
↔ List<
InspectableProperty> -
The list of inspectable property descriptors for this object.
getter/setter pairinherited
- readOnly ↔ bool?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scopesRoute ↔ bool?
-
getter/setter pair
- selected ↔ bool?
-
getter/setter pair
- textField ↔ bool?
-
getter/setter pair
- value ↔ String?
-
getter/setter pair
- widgetName → String
-
no setteroverride
Methods
-
getProperty(
String name) → InspectableProperty? -
Returns the first property whose
InspectableProperty.namematchesname, ornullif no such property exists.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeProperty(
String name) → void -
Removes the property with the given
namefromproperties.inherited -
toJson(
) → dynamic -
toJson returns a json compatible object.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
toWidget(
) → Widget -
Get a Flutter widget equivalent object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
dynamic data) → NapaSemantics? -
Deserialize a json compatible object into a NapaWidget or null.
override